Model:
    - Vincenzo Arcidiacono <vincenzo.arcidiacono@ext.ec.europa.eu>
    - Georgios Fontaras <georgios.fontaras@ec.europa.eu>
    - Dimitrios Komnos <dimitrios.komnos@ext.ec.europa.eu>
    - Jelica Pavlovic <jelica.pavlovic@ext.ec.europa.eu>
    - Alessandro Tansini <alessandro.tansini@ec.europa.eu>

Documentation:
    - Vincenzo Arcidiacono <vincenzo.arcidiacono@ext.ec.europa.eu>
    - Dimitrios Komnos <dimitrios.komnos@ext.ec.europa.eu>
    - Francesca Saporiti <francesca.saporiti@ext.ec.europa.eu>
    - Alessandro Tansini <alessandro.tansini@ec.europa.eu>

Past contributors:
    - Kostis Anagnostopoulos <kostis.anagnostopoulos@ext.ec.europa.eu>
    - Biagio Ciuffo <biagio.ciuffo@ec.europa.eu>
    - Stefano Corsi <stefano.corsi@ext.ec.europa.eu>
    - Spyridon Konstantinidis <Spyridon.konstantinidis@ext.ec.europa.eu>
    - Ashenafi Makie <ashenafi.makie@ext.ec.europa.eu>
    - Iker Prado Rujas <iker.prado-rujas@ext.ec.europa.eu>
    - Stefanos Tsiamakis <stsiakma@gmail.com>
    - Victor Valverde <victor.valverde-morales@ec.europa.eu>